@@ -15,6 +15,7 @@ class Timeline(object):
         self._scheduled = []
         self._time_factor = 1
         self._time_correction = TimeCorrection(start_time, current_time)
+
     def set_time_factor(self, factor):
         """
         Sets the time factor -- the factor by which the virtual time advances compared to the real
@@ -32,24 +33,36 @@ class Timeline(object):
         """
         return self._time_factor
 
+    def freeze(self):
+        """
+        Shortcut for :func:`.set_time_factor`(0)
+        """
+        self.set_time_factor(0)
+
     def _correct_time(self):
         self._time_correction.virtual_time = self.time()
         self._time_correction.real_time = _real_time()
         self._time_correction.shift = 0 # shift stems from the previous correction...
+
     def sleep(self, seconds):
         """
         Sleeps a given number of seconds in the virtual timeline
         """
         if seconds < 0:
             raise ValueError("Cannot sleep negative number of seconds")
-        self.set_time(self.time() + seconds)
+        if self._time_factor == 0:
+            self.set_time(self.time() + seconds)
+        else:
+            _real_sleep(seconds / self._time_factor)
         self.trigger_past_callbacks()
+
     def sleep_wait_all_scheduled(self):
         """
         Sleeps enough time for all scheduled callbacks to occur
         """
         while self._scheduled:
             self.sleep(max(0, self._scheduled[0][0]-self.time()))
+
     def trigger_past_callbacks(self):
         current_time = self.time()
         while self._scheduled and self._scheduled[0][0] <= current_time:
